@@ -30,7 +30,6 @@ describe 'barbican::plugins::p11_crypto' do
           :p11_crypto_plugin_mkek_length               => 32,
           :p11_crypto_plugin_hmac_label                => 'hmac_label',
           :p11_crypto_plugin_token_serial_number       => 'token_serial',
-          :p11_crypto_plugin_token_label               => 'token_label',
           :p11_crypto_plugin_token_labels              => 'token_label1,token_label2',
           :p11_crypto_plugin_slot_id                   => 1,
           :p11_crypto_plugin_library_path              => '/usr/lib/libCryptoki2_64.so',
@@ -55,8 +54,6 @@ describe 'barbican::plugins::p11_crypto' do
           .with_value(params[:p11_crypto_plugin_hmac_label])
         is_expected.to contain_barbican_config('p11_crypto_plugin/token_serial_number') \
           .with_value(params[:p11_crypto_plugin_token_serial_number])
-        is_expected.to contain_barbican_config('p11_crypto_plugin/token_label') \
-          .with_value(params[:p11_crypto_plugin_token_label])
         is_expected.to contain_barbican_config('p11_crypto_plugin/token_labels') \
           .with_value(params[:p11_crypto_plugin_token_labels])
         is_expected.to contain_barbican_config('p11_crypto_plugin/slot_id') \
